@@ -2,7 +2,8 @@ package SyForm::Exception::UnknownErrorOnCreate;
 BEGIN {
   $SyForm::Exception::UnknownErrorOnCreate::AUTHORITY = 'cpan:GETTY';
 }
-$SyForm::Exception::UnknownErrorOnCreate::VERSION = '0.007';
+# ABSTRACT: Exception at SyForm->create
+$SyForm::Exception::UnknownErrorOnCreate::VERSION = '0.008';
 use Moose;
 extends 'SyForm::Exception';
 
@@ -28,11 +29,11 @@ __END__
 
 =head1 NAME
 
-SyForm::Exception::UnknownErrorOnCreate
+SyForm::Exception::UnknownErrorOnCreate - Exception at SyForm->create
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 AUTHOR
 
