@@ -3,9 +3,9 @@ BEGIN {
   $SyForm::Field::Process::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Role for processed fields
-$SyForm::Field::Process::VERSION = '0.007';
+$SyForm::Field::Process::VERSION = '0.008';
 use Moose::Role;
-use namespace::autoclean;
+use namespace::clean;
 
 sub has_value_by_args {
   my ( $self, %args ) = @_;
@@ -114,7 +114,7 @@ SyForm::Field::Process - Role for processed fields
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 AUTHOR
 
