@@ -3,16 +3,21 @@ BEGIN {
   $SyForm::View::Verify::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Trait for SyForm fields of SyForm::Results and SyForm::Values attributes
-$SyForm::View::Verify::VERSION = '0.007';
+$SyForm::View::Verify::VERSION = '0.008';
 use Moose::Role;
-use namespace::autoclean;
+use namespace::clean;
 
-has verify_results => (
+has error_count => (
   is => 'ro',
-  isa => 'Data::Verifier::Results',
-  required => 1,
+  isa => 'Int',
+  lazy_build => 1,
 );
 
+sub _build_error_count {
+  my ( $self ) = @_;
+  $self->results->error_count;
+}
+
 1;
 
 __END__
@@ -25,7 +30,7 @@ SyForm::View::Verify - Trait for SyForm fields of SyForm::Results and SyForm::Va
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 AUTHOR
 
