@@ -3,34 +3,46 @@ BEGIN {
   $SyForm::ViewField::Verify::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: Trait for SyForm fields of SyForm::Results and SyForm::Values attributes
-$SyForm::ViewField::Verify::VERSION = '0.007';
+$SyForm::ViewField::Verify::VERSION = '0.008';
 use Moose::Role;
-use namespace::autoclean;
+use namespace::clean;
 
 sub is_invalid {
   my ( $self ) = @_;
-  return $self->results->verify_results->is_invalid($self->name) ? 1 : 0;
+  return $self->is_valid ? 0 : 1;
 }
 
-sub is_valid {
+has is_valid => (
+  is => 'ro',
+  isa => 'Int',
+  lazy_build => 1,
+);
+
+sub _build_is_valid {
   my ( $self ) = @_;
-  return $self->results->verify_results->is_invalid($self->name) ? 0 : 1;
+  return $self->results->validation_class->is_valid($self->name) ? 1 : 0;
 }
 
-sub is_missing {
+has errors => (
+  is => 'ro',
+  isa => 'ArrayRef',
+  lazy_build => 1,
+);
+
+sub _build_errors {
   my ( $self ) = @_;
-  return $self->results->verify_results->is_missing($self->name) ? 1 : 0;
+  return [ $self->results->validation_class->get_errors($self->name) ];
 }
 
-sub has_original_value {
-  my ( $self ) = @_;
-  return $self->has_value;
-}
+# sub has_original_value {
+#   my ( $self ) = @_;
+#   return $self->has_value;
+# }
 
-sub original_value {
-  my ( $self ) = @_;
-  return $self->results->verify_results->get_original_value($self->name);
-}
+# sub original_value {
+#   my ( $self ) = @_;
+#   return $self->results->verify_results->get_original_value($self->name);
+# }
 
 1;
 
@@ -44,7 +56,7 @@ SyForm::ViewField::Verify - Trait for SyForm fields of SyForm::Results and SyFor
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 AUTHOR
 
